@@ -1,7 +1,7 @@
 package CPANPLUS::Error;
 
 use strict;
-use CPANPLUS::inc;
+
 use Log::Message private => 0;;
 
 =pod
@@ -12,7 +12,7 @@ CPANPLUS::Error
 
 =head1 SYNOPSIS
 
-    use CPANPLUS::Error qw[msg error];
+    use CPANPLUS::Error qw[cp_msg cp_error];
 
 =head1 DESCRIPTION
 
@@ -21,20 +21,28 @@ libraries, and is mainly intended for internal use.
 
 =head1 FUNCTIONS
 
-=head2 msg("message string" [,VERBOSE])
+=head2 cp_msg("message string" [,VERBOSE])
 
 Records a message on the stack, and prints it to C<STDOUT> (or actually
 C<$MSG_FH>, see the C<GLOBAL VARIABLES> section below), if the
 C<VERBOSE> option is true.
 The C<VERBOSE> option defaults to false.
 
-=head2 error("error string" [,VERBOSE])
+=head2 msg()
+
+An alias for C<cp_msg>.
+
+=head2 cp_error("error string" [,VERBOSE])
 
 Records an error on the stack, and prints it to C<STDERR> (or actually
 C<$ERROR_FH>, see the C<GLOBAL VARIABLES> sections below), if the
 C<VERBOSE> option is true.
 The C<VERBOSE> options defaults to true.
 
+=head2 error()
+
+An alias for C<cp_error>.
+
 =head1 CLASS METHODS
 
 =head2 CPANPLUS::Error->stack()
@@ -65,18 +73,27 @@ BEGIN {
     use vars            qw[@EXPORT @ISA $ERROR_FH $MSG_FH];
 
     @ISA        = 'Exporter';
-    @EXPORT     = qw[error msg];
+    @EXPORT     = qw[cp_error cp_msg error msg];
 
     my $log     = new Log::Message;
 
     for my $func ( @EXPORT ) {
         no strict 'refs';
+        
+        my $prefix  = 'cp_';
+        my $name    = $func;
+        $name       =~ s/^$prefix//g;
+        
         *$func = sub {
                         my $msg     = shift;
+                        
+                        ### no point storing non-messages
+                        return unless defined $msg;
+                        
                         $log->store(
                                 message => $msg,
-                                tag     => uc $func,
-                                level   => $func,
+                                tag     => uc $name,
+                                level   => $prefix . $name,
                                 extra   => [@_]
                         );
                 };
@@ -126,7 +143,7 @@ use Carp ();
 
 {
 
-    sub msg {
+    sub cp_msg {
         my $self    = shift;
         my $verbose = shift;
 
@@ -134,13 +151,14 @@ use Carp ();
         return if defined $verbose && $verbose == 0;
 
         my $old_fh = select $CPANPLUS::Error::MSG_FH;
-        print '['. $self->tag (). '] ' . $self->message . "\n";
+
+        print '['. $self->tag . '] ' . $self->message . "\n";
         select $old_fh;
 
         return;
     }
 
-    sub error {
+    sub cp_error {
         my $self    = shift;
         my $verbose = shift;
 
@@ -154,7 +172,7 @@ use Carp ();
 
         ### maybe we didn't initialize an internals object (yet) ###
         my $debug   = $cb ? $cb->configure_object->get_conf('debug') : 0;
-        my $msg     = '['. $self->tag . '] ' . $self->message;
+        my $msg     =  '['. $self->tag . '] ' . $self->message . "\n";
 
         ### i'm getting this warning in the test suite:
         ### Ambiguous call resolved as CORE::warn(), qualify as such or
