@@ -1,11 +1,12 @@
 package CPANPLUS::Internals::Utils;
 
 use strict;
-use CPANPLUS::inc;
+
 use CPANPLUS::Error;
 use CPANPLUS::Internals::Constants;
 
-use File::Copy                  qw[move];
+use Cwd;
+use File::Copy;
 use Params::Check               qw[check];
 use Module::Load::Conditional   qw[can_load];
 use Locale::Maketext::Simple    Class => 'CPANPLUS', Style => 'gettext';
@@ -39,7 +40,7 @@ CPANPLUS libraries.
 
 =head1 METHODS
 
-=head2 _mkdir( dir => '/some/dir' )
+=head2 $cb->_mkdir( dir => '/some/dir' )
 
 C<_mkdir> creates a full path to a directory.
 
@@ -56,7 +57,9 @@ sub _mkdir {
         dir     => { required => 1 },
     };
 
-    my $args = check( $tmpl, \%hash ) or return;
+    my $args = check( $tmpl, \%hash ) or (
+        error(loc( Params::Check->last_error ) ), return
+    );       
 
     unless( can_load( modules => { 'File::Path' => 0.0 } ) ) {
         error( loc("Could not use File::Path! This module should be core!") );
@@ -76,7 +79,7 @@ sub _mkdir {
 
 =pod
 
-=head2 _chdir( dir => '/some/dir' )
+=head2 $cb->_chdir( dir => '/some/dir' )
 
 C<_chdir> changes directory to a dir.
 
@@ -104,7 +107,7 @@ sub _chdir {
 
 =pod
 
-=head2 _rmdir( dir => '/some/dir' );
+=head2 $cb->_rmdir( dir => '/some/dir' );
 
 Removes a directory completely, even if it is non-empty.
 
@@ -140,7 +143,7 @@ sub _rmdir {
 
 =pod
 
-=head2 _perl_version ( perl => 'some/perl/binary' );
+=head2 $cb->_perl_version ( perl => 'some/perl/binary' );
 
 C<_perl_version> returns the version of a certain perl binary.
 It does this by actually running a command.
@@ -153,22 +156,33 @@ sub _perl_version {
     my $self = shift;
     my %hash = @_;
 
+    my $perl;
     my $tmpl = {
-        perl    => { required => 1 },
+        perl    => { required => 1, store => \$perl },
     };
 
-    my $args = check( $tmpl, \%hash ) or return;
-    my $cmd  = $args->{'perl'} .
+    check( $tmpl, \%hash ) or return;
+    
+    my $perl_version;
+    ### special perl, or the one we are running under?
+    if( $perl eq $^X ) {
+        ### just load the config        
+        require Config;
+        $perl_version = $Config::Config{version};
+        
+    } else {
+        my $cmd  = $perl .
                 ' -MConfig -eprint+Config::config_vars+version';
-    my ($perl_version) = (`$cmd` =~ /version='(.*)'/);
-
+        ($perl_version) = (`$cmd` =~ /version='(.*)'/);
+    }
+    
     return $perl_version if defined $perl_version;
     return;
 }
 
 =pod
 
-=head2 _version_to_number( version => $version );
+=head2 $cb->_version_to_number( version => $version );
 
 Returns a proper module version, or '0.0' if none was available.
 
@@ -191,7 +205,7 @@ sub _version_to_number {
 
 =pod
 
-=head2 _whoami
+=head2 $cb->_whoami
 
 Returns the name of the subroutine you're currently in.
 
@@ -224,7 +238,7 @@ sub _get_file_contents {
     return $contents;
 }
 
-=pod _move( from => $file|$dir, to => $target );
+=pod $cb->_move( from => $file|$dir, to => $target );
 
 Moves a file or directory to the target.
 
@@ -253,6 +267,127 @@ sub _move {
     }
 }
 
+=pod $cb->_copy( from => $file|$dir, to => $target );
+
+Moves a file or directory to the target.
+
+Returns true on success, false on failure.
+
+=cut
+
+sub _copy {
+    my $self = shift;
+    my %hash = @_;
+    
+    my($from,$to);
+    my $tmpl = {
+        file    =>{ required => 1, allow => [IS_FILE,IS_DIR],
+                        store => \$from },
+        to      => { required => 1, store => \$to }
+    };
+
+    check( $tmpl, \%hash ) or return;
+
+    if( File::Copy::copy( $from, $to ) ) {
+        return 1;
+    } else {
+        error(loc("Failed to copy '%1' to '%2': %3", $from, $to, $!));
+        return;
+    }
+}
+
+=head2 $cb->_mode_plus_w( file => '/path/to/file' );
+
+Sets the +w bit for the file.
+
+Returns true on success, false on failure.
+
+=cut
+
+sub _mode_plus_w {
+    my $self = shift;
+    my %hash = @_;
+    
+    require File::stat;
+    
+    my $file;
+    my $tmpl = {
+        file    => { required => 1, allow => IS_FILE, store => \$file },
+    };
+    
+    check( $tmpl, \%hash ) or return;
+    
+    ### set the mode to +w for a file and +wx for a dir
+    my $x       = File::stat::stat( $file );
+    my $mask    = -d $file ? 0100 : 0200;
+    
+    if( $x and chmod( $x->mode|$mask, $file ) ) {
+        return 1;
+
+    } else {        
+        error(loc("Failed to '%1' '%2': '%3'", 'chmod +w', $file, $!));
+        return;
+    }
+}    
+
+=head2 $uri = $cb->_host_to_uri( scheme => SCHEME, host => HOST, path => PATH );
+
+Turns a CPANPLUS::Config style C<host> entry into an URI string.
+
+Returns the uri on success, and false on failure
+
+=cut
+
+sub _host_to_uri {
+    my $self = shift;
+    my %hash = @_;
+    
+    my($scheme, $host, $path);
+    my $tmpl = {
+        scheme  => { required => 1,     store => \$scheme },
+        host    => { default  => '',    store => \$host },
+        path    => { default  => '',    store => \$path },
+    };       
+
+    check( $tmpl, \%hash ) or return;
+
+    $host ||= 'localhost';
+
+    return "$scheme://" . File::Spec::Unix->catdir( $host, $path ); 
+}
+
+=head2 $cb->_vcmp( VERSION, VERSION );
+
+Normalizes the versions passed and does a '<=>' on them, returning the result.
+
+=cut
+
+sub _vcmp {
+    my $self = shift;
+    my ($x, $y) = @_;
+    
+    s/_//g foreach $x, $y;
+
+    return $x <=> $y;
+}
+
+=head2 $cb->_homedir
+
+Returns the user's homedir, or C<cwd> if it could not be found
+
+=cut
+
+sub _home_dir {
+    my @os_home_envs = qw( APPDATA HOME USERPROFILE WINDIR SYS$LOGIN );
+
+    for my $env ( @os_home_envs ) {
+        next unless exists $ENV{ $env };
+        next unless defined $ENV{ $env } && length $ENV{ $env };
+        return $ENV{ $env } if -d $ENV{ $env };
+    }
+
+    return cwd();
+}
 
 1;
 
